@@ -27,8 +27,6 @@
 
 #include "pygobject-private.h"
 
-static const gchar *pygenum_class_id     = "PyGEnum::class";
-static GQuark       pygenum_class_key    = 0;
 
 #define GET_INT(x) (((PyIntObject*)x)->ob_ival)
 static int
@@ -89,7 +87,7 @@ pyg_enum_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
     if (!pytc)
 	return NULL;
     
-    if (!PyObject_TypeCheck(pytc, &PyGEnum_Type)) {
+    if (!PyObject_TypeCheck(pytc, &PyGTypeWrapper_Type)) {
 	Py_DECREF(pytc);
 	PyErr_SetString(PyExc_TypeError,
 			"__gtype__ attribute not a typecode");
@@ -123,8 +121,12 @@ pyg_enum_new(PyTypeObject *type, PyObject *args, PyObject *kwargs)
     g_type_class_unref(eclass);
     
     ret = PyDict_GetItem(values, PyInt_FromLong(value));
-    Py_INCREF(ret);
     Py_DECREF(values);
+    if (ret)
+        Py_INCREF(ret);
+    else
+	PyErr_Format(PyExc_ValueError, "invalid enum value: %ld", value);
+    
     return ret;
 }
 
@@ -166,7 +168,7 @@ pyg_enum_add (PyObject *   module,
 	      GType        gtype)
 {
     PyGILState_STATE state;
-    PyObject *instance_dict, *stub, *values;
+    PyObject *instance_dict, *stub, *values, *o;
     GEnumClass *eclass;
     int i;
     
@@ -186,16 +188,20 @@ pyg_enum_add (PyObject *   module,
 	return NULL;
     }
 
+    ((PyTypeObject *)stub)->tp_flags &= ~Py_TPFLAGS_BASETYPE;
+    ((PyTypeObject *)stub)->tp_new = pyg_enum_new;
+
     if (module)
 	PyDict_SetItemString(((PyTypeObject *)stub)->tp_dict,
 			     "__module__",
 			     PyString_FromString(PyModule_GetName(module)));
     
-    if (!pygenum_class_key)
-        pygenum_class_key = g_quark_from_static_string(pygenum_class_id);
-
     g_type_set_qdata(gtype, pygenum_class_key, stub);
 
+    o = pyg_type_wrapper_new(gtype);
+    PyDict_SetItemString(((PyTypeObject *)stub)->tp_dict, "__gtype__", o);
+    Py_DECREF(o);
+
     if (module) {
 	/* Add it to the module name space */
 	PyModule_AddObject(module, (char*)typename, stub);
@@ -270,6 +276,7 @@ pyg_enum_get_value_nick(PyGEnum *self, void *closure)
   return retval;
 }
 
+
 static PyGetSetDef pyg_enum_getsets[] = {
     { "value_name", (getter)pyg_enum_get_value_name, (setter)0 },
     { "value_nick", (getter)pyg_enum_get_value_nick, (setter)0 },
@@ -313,7 +320,7 @@ PyTypeObject PyGEnum_Type = {
 	0,					  /* tp_descr_get */
 	0,					  /* tp_descr_set */
 	0,					  /* tp_dictoffset */
-	0,					  /* tp_init */
+	0,				  	  /* tp_init */
 	0,					  /* tp_alloc */
 	pyg_enum_new,				  /* tp_new */
 };
